@@ -9,6 +9,45 @@
 #ifndef EBADR
 #define EBADR 0
 #endif
+#ifndef SEEK_DATA
+#define SEEK_DATA 0
+#endif
+#ifndef SEEK_HOLE
+#define SEEK_HOLE 0
+#endif
+#ifndef POSIX_FADV_NORMAL
+#define POSIX_FADV_NORMAL 0
+#endif
+#ifndef POSIX_FADV_SEQUENTIAL
+#define POSIX_FADV_SEQUENTIAL 0
+#endif
+#ifndef POSIX_FADV_RANDOM
+#define POSIX_FADV_RANDOM 0
+#endif
+#ifndef POSIX_FADV_NOREUSE
+#define POSIX_FADV_NOREUSE 0
+#endif
+#ifndef POSIX_FADV_WILLNEED
+#define POSIX_FADV_WILLNEED 0
+#endif
+#ifndef POSIX_FADV_DONTNEED
+#define POSIX_FADV_DONTNEED 0
+#endif
+#ifndef POSIX_MADV_NORMAL
+#define POSIX_MADV_NORMAL 0
+#endif
+#ifndef POSIX_MADV_SEQUENTIAL
+#define POSIX_MADV_SEQUENTIAL 0
+#endif
+#ifndef POSIX_MADV_RANDOM
+#define POSIX_MADV_RANDOM 0
+#endif
+#ifndef POSIX_MADV_WILLNEED
+#define POSIX_MADV_WILLNEED 0
+#endif
+#ifndef POSIX_MADV_DONTNEED
+#define POSIX_MADV_DONTNEED 0
+#endif
 #ifndef O_RDONLY
 #define O_RDONLY 0
 #endif
@@ -105,39 +144,6 @@
 #ifndef S_IFMT
 #define S_IFMT 0
 #endif
-#ifndef POSIX_FADV_NORMAL
-#define POSIX_FADV_NORMAL 0
-#endif
-#ifndef POSIX_FADV_SEQUENTIAL
-#define POSIX_FADV_SEQUENTIAL 0
-#endif
-#ifndef POSIX_FADV_RANDOM
-#define POSIX_FADV_RANDOM 0
-#endif
-#ifndef POSIX_FADV_NOREUSE
-#define POSIX_FADV_NOREUSE 0
-#endif
-#ifndef POSIX_FADV_WILLNEED
-#define POSIX_FADV_WILLNEED 0
-#endif
-#ifndef POSIX_FADV_DONTNEED
-#define POSIX_FADV_DONTNEED 0
-#endif
-#ifndef POSIX_MADV_NORMAL
-#define POSIX_MADV_NORMAL 0
-#endif
-#ifndef POSIX_MADV_SEQUENTIAL
-#define POSIX_MADV_SEQUENTIAL 0
-#endif
-#ifndef POSIX_MADV_RANDOM
-#define POSIX_MADV_RANDOM 0
-#endif
-#ifndef POSIX_MADV_WILLNEED
-#define POSIX_MADV_WILLNEED 0
-#endif
-#ifndef POSIX_MADV_DONTNEED
-#define POSIX_MADV_DONTNEED 0
-#endif
 #ifndef ST_RDONLY
 #define ST_RDONLY 0
 #endif
@@ -192,12 +198,12 @@
 #ifndef MAP_SHARED
 #define MAP_SHARED 0
 #endif
+#ifndef MAP_FIXED
+#define MAP_FIXED 0
+#endif
 #ifndef MAP_ANONYMOUS
 #define MAP_ANONYMOUS 0
 #endif
-#ifndef MAP_HUGETLB
-#define MAP_HUGETLB 0
-#endif
 #ifndef MAP_LOCKED
 #define MAP_LOCKED 0
 #endif
@@ -210,6 +216,18 @@
 #ifndef MAP_NONBLOCK
 #define MAP_NONBLOCK 0
 #endif
+#ifndef MAP_GROWSDOWN
+#define MAP_GROWSDOWN 0
+#endif
+#ifndef MAP_32BIT
+#define MAP_32BIT 0
+#endif
+#ifndef MAP_HUGETLB
+#define MAP_HUGETLB 0
+#endif
+#ifndef MAP_STACK
+#define MAP_STACK 0
+#endif
 #ifndef FIEMAP_FLAG_SYNC
 #define FIEMAP_FLAG_SYNC 0
 #endif
@@ -264,9 +282,3 @@
 #ifndef SPLICE_F_GIFT
 #define SPLICE_F_GIFT 0
 #endif
-#ifndef SEEK_DATA
-#define SEEK_DATA 0
-#endif
-#ifndef SEEK_HOLE
-#define SEEK_HOLE 0
-#endif
